@@ -176,18 +176,27 @@ class EasyCodeReaderServer:
                     }
                 ),
                 Tool(
-                    name="list_project_tree",
-                    description="递归列出指定 Java 项目的目录结构，只包含源代码文件（.java）、配置文件和文件夹，过滤编译产物",
+                    name="list_project_files",
+                    description=(
+                        "列出 Java 项目中的源代码文件和配置文件路径。"
+                        "支持两种模式：1) 列出整个项目的所有文件；2) 指定子目录（如 'core' 或 'address/src/main/java'）仅列出该目录下的文件。"
+                        "返回相对路径列表，已自动过滤测试目录（src/test）、编译产物（target/build）和 IDE 配置等无关文件。"
+                        "适合在阅读代码前先了解项目结构，或当项目文件过多时聚焦特定模块。"
+                    ),
                     inputSchema={
                         "type": "object",
                         "properties": {
                             "project_name": {
                                 "type": "string",
-                                "description": "项目名称（例如: my-project）"
+                                "description": "项目名称（例如: nacos）"
+                            },
+                            "sub_path": {
+                                "type": "string",
+                                "description": "可选：指定项目内的子目录路径，只列出该目录下的文件（例如: 'core' 或 'address/src/main/java'）。不指定则列出整个项目"
                             },
                             "project_dir": {
                                 "type": "string",
-                                "description": "项目目录路径（可选，如果未提供则使用启动时配置的路径）"
+                                "description": "可选：项目所在的父目录路径。如果未提供则使用服务器启动时配置的路径"
                             }
                         },
                         "required": ["project_name"]
@@ -206,8 +215,8 @@ class EasyCodeReaderServer:
                     return await self._read_project_code(**arguments)
                 elif name == "list_all_project":
                     return await self._list_all_project(**arguments)
-                elif name == "list_project_tree":
-                    return await self._list_project_tree(**arguments)
+                elif name == "list_project_files":
+                    return await self._list_project_files(**arguments)
                 else:
                     raise ValueError(f"Unknown tool: {name}")
             except Exception as e:
@@ -458,14 +467,21 @@ class EasyCodeReaderServer:
             logger.error(f"Error listing projects: {e}", exc_info=True)
             return [TextContent(type="text", text=f"列举项目时出错: {str(e)}")]
 
-    async def _list_project_tree(self, project_name: str, project_dir: Optional[str] = None) -> List[TextContent]:
+    async def _list_project_files(self, project_name: str, sub_path: Optional[str] = None, 
+                                   project_dir: Optional[str] = None) -> List[TextContent]:
         """
-        递归列出指定 Java 项目的目录结构
-        只包含源代码文件（.java）、配置文件和文件夹，过滤编译产物和不必要的文件
+        列出 Java 项目中的源代码文件和配置文件路径
+        
+        支持两种模式：
+        1. 列出整个项目的所有文件（sub_path 为 None）
+        2. 只列出指定子目录下的文件（sub_path 指定子目录路径）
+        
+        已自动过滤测试目录（src/test）、编译产物和不必要的文件
 
         参数:
             project_name: 项目名称
-            project_dir: 项目目录路径（可选）
+            sub_path: 可选，项目内的子目录路径（如 'core' 或 'address/src/main/java'）
+            project_dir: 可选，项目所在的父目录路径
         """
         # 确定使用的项目目录
         target_dir = None
@@ -488,6 +504,19 @@ class EasyCodeReaderServer:
                 text=f"错误: {project_name} 项目不存在，请执行 list_all_project tool 检查项目是否存在"
             )]
 
+        # 如果指定了子路径，验证并调整起始路径
+        start_path = project_path
+        search_prefix = ""
+        if sub_path:
+            sub_path = sub_path.strip().strip('/')  # 清理路径
+            start_path = project_path / sub_path
+            if not start_path.exists() or not start_path.is_dir():
+                return [TextContent(
+                    type="text",
+                    text=f"错误: 子目录 '{sub_path}' 在项目 {project_name} 中不存在"
+                )]
+            search_prefix = sub_path
+
         # 需要忽略的目录
         IGNORED_DIRS = {
             'target', 'build', 'out', 'bin',  # 编译输出目录
@@ -495,8 +524,14 @@ class EasyCodeReaderServer:
             '.git', '.svn', '.hg',  # 版本控制
             '.idea', '.vscode', '.eclipse', '.settings',  # IDE 配置
             '__pycache__', '.pytest_cache',  # Python 相关
-            '.gradle', '.mvn'  # 构建工具缓存
+            '.gradle', '.mvn',  # 构建工具缓存
+            'test', 'tests'  # 测试目录
         }
+        
+        # 需要忽略的路径模式（相对路径）
+        IGNORED_PATH_PATTERNS = [
+            'src/test',  # Maven/Gradle 测试目录
+        ]
 
         # 需要包含的文件扩展名（源代码和配置文件）
         INCLUDED_EXTENSIONS = {
@@ -526,20 +561,26 @@ class EasyCodeReaderServer:
             # 检查文件扩展名
             return any(filename.endswith(ext) for ext in INCLUDED_EXTENSIONS)
 
-        def build_tree(path: Path, relative_path: str = "") -> dict:
+        def should_ignore_path(relative_path: str) -> bool:
+            """判断路径是否应该被忽略"""
+            for pattern in IGNORED_PATH_PATTERNS:
+                if pattern in relative_path or relative_path.startswith(pattern):
+                    return True
+            return False
+
+        # 收集所有符合条件的文件路径
+        file_paths = []
+
+        def collect_files(path: Path, relative_path: str = ""):
             """
-            构建目录树，只包含有用的文件
+            递归收集符合条件的文件路径
             
             参数:
                 path: 当前路径
-                relative_path: 相对于项目根目录的路径（用于在结果中显示）
+                relative_path: 相对于项目根目录的路径
             """
-            node: dict = {"type": "dir", "children": {}}
-            
             try:
-                items = sorted(path.iterdir(), key=lambda p: (not p.is_dir(), p.name))
-                
-                for item in items:
+                for item in sorted(path.iterdir(), key=lambda p: p.name):
                     # 跳过隐藏文件和目录
                     if item.name.startswith('.') and item.name not in {'.gitignore', '.dockerignore'}:
                         continue
@@ -549,54 +590,31 @@ class EasyCodeReaderServer:
                         if item.name in IGNORED_DIRS:
                             continue
                         
-                        # 递归构建子目录
+                        # 构建相对路径
                         child_relative = f"{relative_path}/{item.name}" if relative_path else item.name
-                        subtree = build_tree(item, child_relative)
                         
-                        # 只有当子目录包含有用内容时才添加
-                        if subtree["children"]:
-                            node["children"][item.name] = subtree
+                        # 检查路径是否应该被忽略
+                        if should_ignore_path(child_relative):
+                            continue
+                        
+                        # 递归处理子目录
+                        collect_files(item, child_relative)
                     else:
                         # 只包含指定的文件类型
                         if should_include_file(item.name):
                             file_relative = f"{relative_path}/{item.name}" if relative_path else item.name
-                            node["children"][item.name] = {
-                                "type": "file",
-                                "path": file_relative
-                            }
+                            file_paths.append(file_relative)
             except Exception as e:
                 logger.warning(f"遍历目录 {path} 时出错: {e}")
-            
-            return node
 
-        tree = {project_path.name: build_tree(project_path)}
-
-        # 统计信息
-        def count_items(node: dict) -> tuple:
-            """统计目录和文件数量"""
-            dir_count = 0
-            file_count = 0
-            if node.get("type") == "dir":
-                dir_count = 1
-                for child in node.get("children", {}).values():
-                    child_dirs, child_files = count_items(child)
-                    dir_count += child_dirs
-                    file_count += child_files
-            elif node.get("type") == "file":
-                file_count = 1
-            return dir_count, file_count
-
-        total_dirs, total_files = count_items(tree[project_path.name])
+        collect_files(start_path, search_prefix)
 
         result = {
             "project_name": project_name,
             "project_dir": str(project_path),
-            "summary": {
-                "total_directories": total_dirs,
-                "total_files": total_files,
-                "note": "仅包含源代码文件（.java）、配置文件和文件夹，已过滤编译产物"
-            },
-            "tree": tree
+            "search_scope": sub_path if sub_path else "entire project",
+            "total_files": len(file_paths),
+            "files": sorted(file_paths)
         }
 
         return [TextContent(type="text", text=json.dumps(result, indent=2, ensure_ascii=False))]
